==> nextcloud-app-mail-5.5.1-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/lv.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Iegultais ziņojums%s",
    "Important mail" : "Svarīgs pasts",
    "Important" : "Svarīgi",
    "Work" : "Darbs",
    "Personal" : "Personīgs",
    "Later" : "Vēlāk",
    "Mail" : "E-pasts",
    "Mails" : "E-pasta sūtījumi",
    "💌 A mail app for Nextcloud" : "Nextcloud e-pasta lietotne",
    "Your session has expired. The page will be reloaded." : "Sesijai ir beidzies derīgums. Lapa tiks pārlādēta.",
    "Connecting" : "Savienojuma izveide",
    "Save" : "Saglabāt",
    "Connect" : "Savienoties",
    "Configuration discovery failed. Please use the manual settings" : "Konfigurācijas atklāšana neizdevās. Lūgums izmantot pašrocīgu iestatīšanu",
    "Password required" : "Nepieciešama parole",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Konts atjaunināts. Lūgums sekot uznirstošajām norādēm, lai atkārtoti savienotu savu Google kontu",
    "Account updated. Please follow the pop-up instructions to reconnect your Microsoft account" : "Konts atjaunināts. Lūgums sekot uznirstošajām norādēm, lai atkārtoti savienotu savu Microsoft kontu",
    "Configuration discovery temporarily not available. Please try again later." : "Konfigurācijas atklāšana īslaicīgi nav pieejama. Lūgums vēlāk mēģināt vēlreiz.",
    "Auto" : "Automātiski",
    "Name" : "Nosaukums",
    "Mail address" : "E-pasta adrese",
    "Password" : "Parole",
    "Manual" : "Pašrocīgi",
    "IMAP Settings" : "IMAP iestatījumi",
    "IMAP Host" : "IMAP serveris",
    "IMAP Security" : "IMAP drošība",
    "None" : "Neviens",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP lietotājs",
    "IMAP Password" : "IMAP parole",
    "SMTP Settings" : "SMTP iestatījumi",
    "SMTP Host" : "SMTP serveris",
    "SMTP Security" : "SMTP drošība",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP lietotājs",
    "SMTP Password" : "SMTP parole",
    "Account settings" : "Konta iestatījumi",
    "Aliases" : "Aizstājvārdi",
    "Signature" : "Paraksts",
    "Filters" : "Filtri",
    "Rename alias" : "Pārdēvēt aizstājvārdu",
    "Go back" : "Atpakaļ",
    "Email address" : "E-pasta adrese",
    "Cancel" : "Atcelt",
    "Accounts" : "Konti",
    "Add mail account" : "Pievienot e-pasta kontu",
    "General" : "Vispārīgi",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Archive" : "Arhīvi",
    "Delete" : "Izdzēst",
    "Search" : "Meklēt",
    "Send" : "Sūtīt",
    "Refresh" : "Atsvaidzināt",
    "Ok" : "Labi",
    "From" : "No",
    "Select account" : "Atlasīt kontu",
    "To" : "Līdz",
    "Subject" : "Temats",
    "Write message …" : "Rakstiet ziņu...",
    "Add attachment from Files" : "Pievienot pielikumu no Datnēm",
    "Enter a date" : "Ievadiet datumu",
    "Choose" : "Izvēlēties",
    "Choose a file to add as attachment" : "Izvēlēties datni, ko pievienot kā pielikumu",
    "Choose a file to share as a link" : "Jāizvēlas datne, ko kopīgot kā saiti",
    "Confirm" : "Apstiprināt",
    "No messages in this folder" : "Šajā mapē nav neviens ziņojums",
    "Later today – {timeLocale}" : "Vēlāk šodien – {timeLocale}",
    "Set reminder for later today" : "Iestatīt atgādinājumu vēlākam šodien",
    "Favorite" : "Izlasē",
    "Read" : "Lasīt",
    "Edit tags" : "Labot birkas",
    "Back" : "Atpakaļ",
    "Load more" : "Ielādēt vairāk",
    "Create event" : "Izveidot notikumu",
    "All day" : "Visas dienas",
    "Attendees" : "Dalībnieki",
    "Description" : "Apraksts",
    "Create" : "Izveidot",
    "Select" : "Atzīmēt",
    "Comment" : "Piebilde",
    "Accept" : "Pieņemt",
    "Decline" : "Noraidīt",
    "More options" : "Vairāk iespēju",
    "Remove" : "Noņemt",
    "email" : "e-pasts",
    "Today" : "Šodien",
    "Other" : "Cits",
    "The sender of this message has asked to be notified when you read this message." : "Šī ziņojuma sūtītājs ir norādījis, ka vēlas saņemt paziņojumu par šī ziņojuma izlasīšanu.",
    "Forward" : "Turpināt",
    "Translate" : "Tulkot",
    "View source" : "Skatīt avotu",
    "Unnamed" : "Nenosaukts",
    "Choose a folder to store the attachment in" : "Jāizvēlas mape, kurā saglabāt pielikumu",
    "Import into calendar" : "Ievietot kalendārā",
    "Download attachment" : "Lejupielādēt pielikumu",
    "Save to Files" : "Saglabāt uz Datnes",
    "Save all to Files" : "Saglabāt visu uz Datnes",
    "The images have been blocked to protect your privacy." : "Attēli tika aizturēti, lai aizsargātu Tavu privātumu.",
    "Show images" : "Parādīt attēlus",
    "Show images temporarily" : "Īslaicīgi parādīt attēlus",
    "Move" : "Pārvietot",
    "Remove account" : "Noņemt kontu",
    "Add folder" : "Pievienot mapi",
    "Folder name" : "Mapes nosaukums",
    "Saving" : "Saglabā",
    "Show all folders" : "Rādīt visas mapes",
    "Collapse folders" : "Sakļaut mapes",
    "Loading …" : "Ielādē…",
    "Delete folder" : "Izdzēst mapi",
    "An error occurred, unable to rename the mailbox." : "Atgadījās kļūda, nevar pārdēvēt pastkasti.",
    "Rename" : "Pārdēvēt",
    "Subscribed" : "Abonēts",
    "New message" : "Jauna ziņa",
    "Draft" : "Melnraksts",
    "Reply" : "Atbildēt",
    "Retry" : "Mēģināt vēlreiz",
    "Autoresponder follows system settings" : "Automātiskais atbildētājs ievēro sistēmas iestatījumus",
    "Message" : "Ziņojums",
    "Copy to clipboard" : "Kopēt starpliktuvē",
    "Add" : "Pievienot",
    "Show more" : "Parādīt vairāk",
    "Clear" : "Notīrīt",
    "Close" : "Aizvērt",
    "Date" : "Datums",
    "Tags" : "Birkas",
    "Select tags" : "Atlasīt birkas",
    "From me" : "No manis",
    "Custom" : "Pielāgots",
    "An error occurred, unable to rename the tag." : "Atgadījās kļūda, nevar pārdēvēt birku.",
    "Delete tag" : "Izdzēst birku",
    "Tag name is a hidden system tag" : "Birkas nosaukums ir slēpta sistēmas birka",
    "Tag already exists" : "Birka jau pastāv",
    "Not found" : "Nav atrasts",
    "Untitled event" : "Nenosaukts notikums",
    "Recipient" : "Saņēmējs",
    "contains" : "saturs",
    "matches" : "atbilst",
    "Priority" : "Svarīgums",
    "Tag" : "Birkas",
    "delete" : "dzēst",
    "Edit" : "Labot",
    "Enable classification of important mails by default" : "Pēc noklusējuma iespējot svarīgu e-pasta ziņojumu šķirošanu",
    "Reset" : "Atiestatīt",
    "Client ID" : "Klienta ID",
    "User" : "Lietotājs",
    "Host" : "Resursdators",
    "Port" : "Ports",
    "Valid until" : "Derīgs līdz",
    "Certificate" : "Sertifikāts",
    "Submit" : "Iesniegt",
    "Group" : "Grupa",
    "Shared" : "Koplietots",
    "Shares" : "Koplietots",
    "Account connected" : "Konts sasaistīts",
    "You can close this window" : "Šo logu var aizvērt.",
    "Connect your mail account" : "Pievienot savu e-pasta kontu",
    "All" : "Visi",
    "Drafts" : "Melnraksti",
    "Favorites" : "Izlases vienumi",
    "All inboxes" : "Visas iesūtnes",
    "Inbox" : "Iesūtne",
    "Junk" : "Nevēlams",
    "Sent" : "Izsūtne",
    "Trash" : "Miskaste",
    "Error while sharing file" : "Kļūda datnes kopīgošanā",
    "{from}\n{subject}" : "{from}\n{subject}",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "Jau tiek apstrādāts ziņojums. Tiks zaudētas visas nesaglabātas izmaiņas, ja turpināsi.",
    "Discard unsaved changes" : "Atmest nesaglabātās izmaiņas",
    "Could not load {tag}{name}{endtag}" : "Nevarēja ielādēt {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Radusies problēma, ielādējot {tag}{name}{endtag}",
    "Error loading message" : "Kļūda ielādējot vēstuli",
    "Forwarding to %s" : "Pārsūtīt uz %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Jāklikšķina šeit, ja nenotiek automātiska pārvirzīšana dažu sekunžu laikā.",
    "Redirect" : "Novirzīt",
    "The link leads to %s" : "Saite, kas ved uz %s",
    "Continue to %s" : "Turpināt %s",
    "Operator" : "Operators"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-app-mail-5.5.3-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/mail/l10n/lv.js <==
OC.L10N.register(
    "mail",
    {
    "Embedded message %s" : "Iegultais ziņojums%s",
    "Important mail" : "Svarīgs pasts",
    "Important" : "Svarīgi",
    "Work" : "Darbs",
    "Personal" : "Personīgs",
    "Later" : "Vēlāk",
    "Mail" : "E-pasts",
    "Mails" : "E-pasta sūtījumi",
    "💌 A mail app for Nextcloud" : "Nextcloud e-pasta lietotne",
    "Your session has expired. The page will be reloaded." : "Sesijai ir beidzies derīgums. Lapa tiks pārlādēta.",
    "Connecting" : "Savienojuma izveide",
    "Save" : "Saglabāt",
    "Connect" : "Savienoties",
    "Configuration discovery failed. Please use the manual settings" : "Konfigurācijas atklāšana neizdevās. Lūgums izmantot pašrocīgu iestatīšanu",
    "Password required" : "Nepieciešama parole",
    "Account updated. Please follow the pop-up instructions to reconnect your Google account" : "Konts atjaunināts. Lūgums sekot uznirstošajām norādēm, lai atkārtoti savienotu savu Google kontu",
    "Account updated. Please follow the pop-up instructions to reconnect your Microsoft account" : "Konts atjaunināts. Lūgums sekot uznirstošajām norādēm, lai atkārtoti savienotu savu Microsoft kontu",
    "Configuration discovery temporarily not available. Please try again later." : "Konfigurācijas atklāšana īslaicīgi nav pieejama. Lūgums vēlāk mēģināt vēlreiz.",
    "Auto" : "Automātiski",
    "Name" : "Nosaukums",
    "Mail address" : "E-pasta adrese",
    "Password" : "Parole",
    "Manual" : "Pašrocīgi",
    "IMAP Settings" : "IMAP iestatījumi",
    "IMAP Host" : "IMAP serveris",
    "IMAP Security" : "IMAP drošība",
    "None" : "Neviens",
    "SSL/TLS" : "SSL/TLS",
    "STARTTLS" : "STARTTLS",
    "IMAP Port" : "IMAP Port",
    "IMAP User" : "IMAP lietotājs",
    "IMAP Password" : "IMAP parole",
    "SMTP Settings" : "SMTP iestatījumi",
    "SMTP Host" : "SMTP serveris",
    "SMTP Security" : "SMTP drošība",
    "SMTP Port" : "SMTP Port",
    "SMTP User" : "SMTP lietotājs",
    "SMTP Password" : "SMTP parole",
    "Account settings" : "Konta iestatījumi",
    "Aliases" : "Aizstājvārdi",
    "Signature" : "Paraksts",
    "Filters" : "Filtri",
    "Rename alias" : "Pārdēvēt aizstājvārdu",
    "Go back" : "Atpakaļ",
    "Email address" : "E-pasta adrese",
    "Cancel" : "Atcelt",
    "Accounts" : "Konti",
    "Add mail account" : "Pievienot e-pasta kontu",
    "General" : "Vispārīgi",
    "Keyboard shortcuts" : "Tastatūras saīsnes",
    "Archive" : "Arhīvi",
    "Delete" : "Izdzēst",
    "Search" : "Meklēt",
    "Send" : "Sūtīt",
    "Refresh" : "Atsvaidzināt",
    "Ok" : "Labi",
    "From" : "No",
    "Select account" : "Atlasīt kontu",
    "To" : "Līdz",
    "Subject" : "Temats",
    "Write message …" : "Rakstiet ziņu...",
    "Add attachment from Files" : "Pievienot pielikumu no Datnēm",
    "Enter a date" : "Ievadiet datumu",
    "Choose" : "Izvēlēties",
    "Choose a file to add as attachment" : "Izvēlēties datni, ko pievienot kā pielikumu",
    "Choose a file to share as a link" : "Jāizvēlas datne, ko kopīgot kā saiti",
    "Confirm" : "Apstiprināt",
    "No messages in this folder" : "Šajā mapē nav neviens ziņojums",
    "Later today – {timeLocale}" : "Vēlāk šodien – {timeLocale}",
    "Set reminder for later today" : "Iestatīt atgādinājumu vēlākam šodien",
    "Favorite" : "Izlasē",
    "Read" : "Lasīt",
    "Edit tags" : "Labot birkas",
    "Back" : "Atpakaļ",
    "Load more" : "Ielādēt vairāk",
    "Create event" : "Izveidot notikumu",
    "All day" : "Visas dienas",
    "Attendees" : "Dalībnieki",
    "Description" : "Apraksts",
    "Create" : "Izveidot",
    "Select" : "Atzīmēt",
    "Comment" : "Piebilde",
    "Accept" : "Pieņemt",
    "Decline" : "Noraidīt",
    "More options" : "Vairāk iespēju",
    "Remove" : "Noņemt",
    "email" : "e-pasts",
    "Today" : "Šodien",
    "Other" : "Cits",
    "The sender of this message has asked to be notified when you read this message." : "Šī ziņojuma sūtītājs ir norādījis, ka vēlas saņemt paziņojumu par šī ziņojuma izlasīšanu.",
    "Forward" : "Turpināt",
    "Translate" : "Tulkot",
    "View source" : "Skatīt avotu",
    "Unnamed" : "Nenosaukts",
    "Choose a folder to store the attachment in" : "Jāizvēlas mape, kurā saglabāt pielikumu",
    "Import into calendar" : "Ievietot kalendārā",
    "Download attachment" : "Lejupielādēt pielikumu",
    "Save to Files" : "Saglabāt uz Datnes",
    "Save all to Files" : "Saglabāt visu uz Datnes",
    "The images have been blocked to protect your privacy." : "Attēli tika aizturēti, lai aizsargātu Tavu privātumu.",
    "Show images" : "Parādīt attēlus",
    "Show images temporarily" : "Īslaicīgi parādīt attēlus",
    "Move" : "Pārvietot",
    "Remove account" : "Noņemt kontu",
    "Add folder" : "Pievienot mapi",
    "Folder name" : "Mapes nosaukums",
    "Saving" : "Saglabā",
    "Show all folders" : "Rādīt visas mapes",
    "Collapse folders" : "Sakļaut mapes",
    "Loading …" : "Ielādē…",
    "Delete folder" : "Izdzēst mapi",
    "An error occurred, unable to rename the mailbox." : "Atgadījās kļūda, nevar pārdēvēt pastkasti.",
    "Rename" : "Pārdēvēt",
    "Subscribed" : "Abonēts",
    "New message" : "Jauna ziņa",
    "Draft" : "Melnraksts",
    "Reply" : "Atbildēt",
    "Retry" : "Mēģināt vēlreiz",
    "Autoresponder follows system settings" : "Automātiskais atbildētājs ievēro sistēmas iestatījumus",
    "Message" : "Ziņojums",
    "Copy to clipboard" : "Kopēt starpliktuvē",
    "Add" : "Pievienot",
    "Show more" : "Parādīt vairāk",
    "Clear" : "Notīrīt",
    "Close" : "Aizvērt",
    "Date" : "Datums",
    "Tags" : "Birkas",
    "Select tags" : "Atlasīt birkas",
    "From me" : "No manis",
    "Custom" : "Pielāgots",
    "An error occurred, unable to rename the tag." : "Atgadījās kļūda, nevar pārdēvēt birku.",
    "Delete tag" : "Izdzēst birku",
    "Tag name is a hidden system tag" : "Birkas nosaukums ir slēpta sistēmas birka",
    "Tag already exists" : "Birka jau pastāv",
    "Not found" : "Nav atrasts",
    "Untitled event" : "Nenosaukts notikums",
    "Recipient" : "Saņēmējs",
    "Help" : "Palīdzība",
    "contains" : "saturs",
    "matches" : "atbilst",
    "Actions" : "Darbības",
    "Priority" : "Svarīgums",
    "Tag" : "Birkas",
    "delete" : "dzēst",
    "Edit" : "Labot",
    "Enable classification of important mails by default" : "Pēc noklusējuma iespējot svarīgu e-pasta ziņojumu šķirošanu",
    "Reset" : "Atiestatīt",
    "Client ID" : "Klienta ID",
    "User" : "Lietotājs",
    "Host" : "Resursdators",
    "Port" : "Ports",
    "Valid until" : "Derīgs līdz",
    "Certificate" : "Sertifikāts",
    "Submit" : "Iesniegt",
    "Group" : "Grupa",
    "Shared" : "Koplietots",
    "Shares" : "Koplietots",
    "Account connected" : "Konts sasaistīts",
    "You can close this window" : "Šo logu var aizvērt.",
    "Connect your mail account" : "Pievienot savu e-pasta kontu",
    "All" : "Visi",
    "Drafts" : "Melnraksti",
    "Favorites" : "Izlases vienumi",
    "All inboxes" : "Visas iesūtnes",
    "Inbox" : "Iesūtne",
    "Junk" : "Nevēlams",
    "Sent" : "Izsūtne",
    "Trash" : "Miskaste",
    "Error while sharing file" : "Kļūda datnes kopīgošanā",
    "{from}\n{subject}" : "{from}\n{subject}",
    "There is already a message in progress. All unsaved changes will be lost if you continue!" : "Jau tiek apstrādāts ziņojums. Tiks zaudētas visas nesaglabātas izmaiņas, ja turpināsi.",
    "Discard unsaved changes" : "Atmest nesaglabātās izmaiņas",
    "Could not load {tag}{name}{endtag}" : "Nevarēja ielādēt {tag}{name}{endtag}",
    "There was a problem loading {tag}{name}{endtag}" : "Radusies problēma, ielādējot {tag}{name}{endtag}",
    "Error loading message" : "Kļūda ielādējot vēstuli",
    "Forwarding to %s" : "Pārsūtīt uz %s",
    "Click here if you are not automatically redirected within the next few seconds." : "Jāklikšķina šeit, ja nenotiek automātiska pārvirzīšana dažu sekunžu laikā.",
    "Redirect" : "Novirzīt",
    "The link leads to %s" : "Saite, kas ved uz %s",
    "Continue to %s" : "Turpināt %s"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
